<template>
    <div class="report-container" v-loading="loading" element-loading-background="rgba(1, 33, 90, 1)">
        <div class="report-overview" >
            <div id="docx">
                <div v-if="noFile" class="empty">{{ text }}</div>
                <div v-else ref="file"></div>
            </div>
        </div>
        <el-button v-if="!loading" class="export-btn" size="small" type="primary" @click="download">满意度报告下载</el-button>
    </div>
</template>

<script>
import {getLocalBLob} from '@/utils/getLocalFile.js'
const docx = require('docx-preview')
window.JSZip = require('jszip')
import Docx from '@/components/docx/index.vue'
import apiList from '@/api/bigScreen/districView.js'
const portal = window.context.portal
export default {
    name: 'docPreview',
    components: { Docx },
    props: {
        options: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loading: false,
            fileId: '',
            noFile: false,
            text: '',
        }
    },
    mounted() {
        let date = JSON.parse(sessionStorage.getItem('searchDate'))
        if (this.options.type === 'satisfaction') {
            this.getSatisfaction(date)
        }
    },
    methods: {
        async initDocx() {
            if (this.fileId) {
                this.noFile = false
                const bLob = await apiList.previewFile(this.fileId)
                docx.renderAsync(bLob, this.$refs.file) // 渲染到页面预览
            } else if (this.fileUrl) {
                this.noFile = false
                const bLob = await getLocalBLob(this.fileUrl)
                docx.renderAsync(bLob, this.$refs.file)
                this.noFile = false // 渲染到页面预览
            } else if (!this.fileUrl && !this.fileId) {
                let searchDate = sessionStorage.getItem('searchDate')
                searchDate = JSON.parse(searchDate)
                this.noFile = true
                this.text = `${searchDate.year}年第${searchDate.quarter}季度暂无报告`
            }
            setTimeout(() => {
                this.loading = false
            },900)
        },
        getSatisfaction(data) {
            this.loading = true
            apiList.getSatisfaction(data, res => {
                if (res) {
                    this.fileId = res.fileList[0].id
                    this.initDocx()
                }
            })
        },
        download() {
            window.open(portal + `/file/v1/downloadFile?fileId=${this.fileId}`, '_self')
        }
    },
}
</script>

<style lang="scss" scoped>
#docx {
    width: 100%;
    height: 100%;

    .docx-wrapper {
        padding: 0 !important;
        width: 100%;

        .docx {
            width: 100% !important;
        }

        section.docx {
            margin-bottom: 0 !important;
        }
    }

    .empty {
        width: 100%;
        height: 100%;
        color: #fff;
        display: flex;
        justify-content: center;
        align-items: center;
        font-size: 20px;
    }
}

.report-container {
    position: relative;
    padding-top: 20px;
    height: 100%;
}

.report-overview {
    height: calc(100% - 35PX);
    overflow: auto;

}

.export-btn {
    position: absolute;
    right: 0px;
    bottom: 0px;
    height: 30PX;
    line-height: 10PX;
    /deep/span {
        font-size: 14PX !important;
    }
    
}
</style>